from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.subscription_status_response import SubscriptionStatusResponse
from typing import cast



def _get_kwargs(
    
) -> dict[str, Any]:
    

    

    

    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/v1/user/subscription",
    }


    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> SubscriptionStatusResponse | None:
    if response.status_code == 200:
        response_200 = SubscriptionStatusResponse.from_dict(response.json())



        return response_200

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[SubscriptionStatusResponse]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient | Client,

) -> Response[SubscriptionStatusResponse]:
    """ Get Stripe Subscription

     Get detailed Stripe subscription information including portal URL for management.

    First updates local subscription status based on Stripe subscription tier (to refresh after
    purchase),
    then fetches detailed subscription information from Stripe Subscriptions API.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SubscriptionStatusResponse]
     """


    kwargs = _get_kwargs(
        
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    *,
    client: AuthenticatedClient | Client,

) -> SubscriptionStatusResponse | None:
    """ Get Stripe Subscription

     Get detailed Stripe subscription information including portal URL for management.

    First updates local subscription status based on Stripe subscription tier (to refresh after
    purchase),
    then fetches detailed subscription information from Stripe Subscriptions API.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SubscriptionStatusResponse
     """


    return sync_detailed(
        client=client,

    ).parsed

async def asyncio_detailed(
    *,
    client: AuthenticatedClient | Client,

) -> Response[SubscriptionStatusResponse]:
    """ Get Stripe Subscription

     Get detailed Stripe subscription information including portal URL for management.

    First updates local subscription status based on Stripe subscription tier (to refresh after
    purchase),
    then fetches detailed subscription information from Stripe Subscriptions API.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[SubscriptionStatusResponse]
     """


    kwargs = _get_kwargs(
        
    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    *,
    client: AuthenticatedClient | Client,

) -> SubscriptionStatusResponse | None:
    """ Get Stripe Subscription

     Get detailed Stripe subscription information including portal URL for management.

    First updates local subscription status based on Stripe subscription tier (to refresh after
    purchase),
    then fetches detailed subscription information from Stripe Subscriptions API.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        SubscriptionStatusResponse
     """


    return (await asyncio_detailed(
        client=client,

    )).parsed
